@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.1-2
+# Application Name - Health Check V0.5.1-3
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -210,7 +210,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.1-2 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.5.1-3 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -318,52 +318,51 @@ class Ui_MainWindow(object):
         g.strip()
         g.lstrip()
         g.rstrip()
-
         
         if g.strip() == "3.2010.02-8":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.1.1")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.1.1")
         elif g.strip() == "3.2010.02-8.002":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.1.1")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.1.1")
         elif g.strip() == "3.2010.02-8.001":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.1.1")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.1.1")
         elif g.strip() == "2.2009.51-1":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.1")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.1")
         elif g.strip() == "2009.51-1.203.2":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.1 UK Generic Version")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.1 UK Generic Version")
         elif g.strip() == "2009.51-1.203.1":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.1 UK Generic Version")
+            self.listWidget.addItem("FirmwareVersion \t\t" + g.strip() + " - PR 1.1 UK Generic Version")
         elif g.strip() == "2009.51-1.205.1":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.1 UK Vodafone Version")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.1 UK Vodafone Version")
         elif g.strip() == "2009.51-1.205.2":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.1 UK Vodafone Version")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.1 UK Vodafone Version")
         elif g.strip() == "1.2009.44-1":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.01")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.01")
         elif g.strip() == "1.2009.42-11":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 - Initial public release ")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1 - Initial public release ")
         elif g.strip() == "1.2009.42-11.002":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 USA Version")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1 USA Version")
         elif g.strip() == "1.2009.42-11.003":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 Mid-East/N-Africa Version")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1 Mid-East/N-Africa Version")
         elif g.strip() == "1.2009.42-11.203":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 UK Generic Version")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1 UK Generic Version")
         elif g.strip() == "1.2009.42-11.203.0":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 UK Generic Version")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1 UK Generic Version")
         elif g.strip() == "1.2009.42-11.203.1":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 UK Generic Version")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1 UK Generic Version")
         elif g.strip() == "1.2009.42-11.203.2":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 UK Generic Version")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1 UK Generic Version")
         elif g.strip() == "1.2009.42-11.205":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 UK Vodafone Version")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1 UK Vodafone Version")
         elif g.strip() == "1.2009.42-11.205.0":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 UK Vodafone Version")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1 UK Vodafone Version")
         elif g.strip() == "1.2009.42-11.205.1":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 UK Vodafone Version")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1 UK Vodafone Version")
         elif g.strip() == "1.2009.42-11.205.2":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 UK Vodafone Version")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1 UK Vodafone Version")
         elif g.strip() == "1.2009.41-1":
-            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - Early Release Vanilla Variant")
+            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - Early Release Vanilla Variant")
         else:
-           self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - Varient unknown")
+           self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - Varient unknown")
 
 
 # Funtion - update CPU Information
@@ -470,6 +469,7 @@ class Ui_MainWindow(object):
         self.pushButton_hw.setText("........")
         self.pushButton_hw.setText("Update")
         self.pushButton_hw.setEnabled(True)
+        self.listWidget.sortItems()
 
     def updateTab2(self):
         self.listWidget2.clear()
@@ -480,6 +480,7 @@ class Ui_MainWindow(object):
         Thread(target=self.Cellular()).start()
         self.pushButton_com.setText("Update")
         self.pushButton_com.setEnabled(True)
+        self.listWidget2.sortItems()
 
     def updateTab3(self):
         self.pushButton_cam.setEnabled(False)
@@ -497,7 +498,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.1-2", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.1-3", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
